aboutsummaryrefslogtreecommitdiff
path: root/azalea-protocol/src/packets/handshake/client_intention_packet.rs
diff options
context:
space:
mode:
authormat <github@matdoes.dev>2022-07-29 15:32:04 -0500
committermat <github@matdoes.dev>2022-07-29 15:32:04 -0500
commit1b602d0be793394ac2b0d009b77c6a877a4efb7d (patch)
tree6d781edb998a362d368b6c65a86af84a91f747ba /azalea-protocol/src/packets/handshake/client_intention_packet.rs
parent4ee4687053b7442f518823b08099c156f4da4e83 (diff)
downloadazalea-drasl-1b602d0be793394ac2b0d009b77c6a877a4efb7d.tar.xz
fix errors and warnings
Diffstat (limited to 'azalea-protocol/src/packets/handshake/client_intention_packet.rs')
-rwxr-xr-xazalea-protocol/src/packets/handshake/client_intention_packet.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/azalea-protocol/src/packets/handshake/client_intention_packet.rs b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
index 804778a0..ef47bba3 100755
--- a/azalea-protocol/src/packets/handshake/client_intention_packet.rs
+++ b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
@@ -1,9 +1,9 @@
use crate::packets::ConnectionProtocol;
use azalea_buf::McBuf;
-use packet_macros::ClientboundHandshakePacket;
+use packet_macros::ServerboundHandshakePacket;
use std::hash::Hash;
#[derive(Hash, Clone, Debug, McBuf, ClientboundHandshakePacket)]
pub struct ClientIntentionPacket {
#[var]
pub protocol_version: u32,
@@ -1,9 +1,9 @@
use std::hash::Hash;
-#[derive(Hash, Clone, Debug, McBuf, ClientboundHandshakePacket)]
+#[derive(Hash, Clone, Debug, McBuf, ServerboundHandshakePacket)]
pub struct ClientIntentionPacket {
#[var]